@@ -32,7 +32,7 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
 
 #define _CONTROL3D_C
-#include "axiom-c-macros.h"
+#include "fricas_c_macros.h"
 #include <string.h>
 #include <stdio.h>
 #include <unistd.h>
@@ -871,7 +871,7 @@ makeControlPanel (void)
 {
 
   Window                cw;
-  int                   i, num;
+  int                   i;
   controlPanelStruct    *control;
   buttonStruct          *buttons;
   controlXY             cXY;
@@ -922,7 +922,7 @@ makeControlPanel (void)
   /* Define and assign a mouse cursor */
   control->controlWindow = cw;
 
-  num = initButtons(control->buttonQueue);
+  initButtons(control->buttonQueue);
   buttons = control->buttonQueue;
   for (i=controlButtonsStart3D; i<(controlButtonsEnd3D); i++) {
     controlAttrib.event_mask = (control->buttonQueue[i]).mask;
@@ -1013,6 +1013,3 @@ putControlPanelSomewhere (int whereDoesPanelGo)
   XFlush(dsply);
 
 }
-
-
-
